Garfield.nn.GCNDecoder
======================

.. currentmodule:: Garfield.nn

.. autoclass:: GCNDecoder

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~GCNDecoder.__init__
      ~GCNDecoder.add_module
      ~GCNDecoder.apply
      ~GCNDecoder.bfloat16
      ~GCNDecoder.buffers
      ~GCNDecoder.children
      ~GCNDecoder.compile
      ~GCNDecoder.cpu
      ~GCNDecoder.cuda
      ~GCNDecoder.double
      ~GCNDecoder.eval
      ~GCNDecoder.extra_repr
      ~GCNDecoder.float
      ~GCNDecoder.forward
      ~GCNDecoder.get_buffer
      ~GCNDecoder.get_extra_state
      ~GCNDecoder.get_parameter
      ~GCNDecoder.get_submodule
      ~GCNDecoder.half
      ~GCNDecoder.ipu
      ~GCNDecoder.load_state_dict
      ~GCNDecoder.modules
      ~GCNDecoder.named_buffers
      ~GCNDecoder.named_children
      ~GCNDecoder.named_modules
      ~GCNDecoder.named_parameters
      ~GCNDecoder.parameters
      ~GCNDecoder.register_backward_hook
      ~GCNDecoder.register_buffer
      ~GCNDecoder.register_forward_hook
      ~GCNDecoder.register_forward_pre_hook
      ~GCNDecoder.register_full_backward_hook
      ~GCNDecoder.register_full_backward_pre_hook
      ~GCNDecoder.register_load_state_dict_post_hook
      ~GCNDecoder.register_module
      ~GCNDecoder.register_parameter
      ~GCNDecoder.register_state_dict_pre_hook
      ~GCNDecoder.requires_grad_
      ~GCNDecoder.set_extra_state
      ~GCNDecoder.share_memory
      ~GCNDecoder.state_dict
      ~GCNDecoder.to
      ~GCNDecoder.to_empty
      ~GCNDecoder.train
      ~GCNDecoder.type
      ~GCNDecoder.xpu
      ~GCNDecoder.zero_grad
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~GCNDecoder.T_destination
      ~GCNDecoder.call_super_init
      ~GCNDecoder.dump_patches
      ~GCNDecoder.training
   
   